From f73b655466092169abac34833fb628fce1fcdebe Mon Sep 17 00:00:00 2001
From: jcduff <jcduff@localhost>
Date: Thu, 23 Oct 2008 14:04:24 +0000
Subject: [PATCH] The commit will bring the following features :     - An updated version of the underlying database. BDB JE 3.3 is now used.     - Attribute API refactoring providing a better abstraction and offering improved performances.     - A new GUI called the Control-Panel to replace the Status-Panel: the specifications for this       GUI are available on OpenDS Wiki and contains a link to a mockup.        See <https://www.opends.org/wiki/page/ControlPanelUISpecification>.     - Some changes in the replication protocol to implement "Assured Replication Mode". The        specifications are on OpenDS Wiki at <https://www.opends.org/wiki/page/AssuredMode> and section 7       described some of the replication changes required to support this. Assured Replication is not finished,       but the main replication protocol changes to support it are done. As explained by Gilles on an email on       the Dev mailing list (http://markmail.org/message/46rgo3meq3vriy4a), with these changes the newer versions       of OpenDS may not be able to replicate with OpenDS 1.0 instances.     - Support for Service Tags on the platforms where the functionality is available and enabled. Specifications       are published at <https://www.opends.org/wiki/page/OpenDSServiceTagEnabled>. For more information on       Service Tags see <http://wikis.sun.com/display/ServiceTag/Sun+Service+Tag+FAQ>.     - The Admin Connector service. In order to provide agentry of the OpenDS server at any time, a new service       has been added, dedicated to the administration, configuration and monitoring of the server.       An overview of the Admin Connector service and it's use is available on the       OpenDS wiki <https://www.opends.org/wiki/page/ManagingAdministrationTrafficToTheServer>     - Updates to the various command line tools to support the Admin Connector service.     - Some internal re-architecting of the server to put the foundation of future developments such as virtual       directory services. The new NetworkGroups and WorkFlow internal services which have been specified in       <https://www.opends.org/wiki/page/BasicOperationRoutingThroughNetworkGroup> are now implemented.     - Many bug fixes...

---
 opends/src/quicksetup/org/opends/quicksetup/Installation.java |   35 ++++++++++++++++++-----------------
 1 files changed, 18 insertions(+), 17 deletions(-)

diff --git a/opends/src/quicksetup/org/opends/quicksetup/Installation.java b/opends/src/quicksetup/org/opends/quicksetup/Installation.java
index 0adbbbf..e032348 100644
--- a/opends/src/quicksetup/org/opends/quicksetup/Installation.java
+++ b/opends/src/quicksetup/org/opends/quicksetup/Installation.java
@@ -208,14 +208,15 @@
   public static final String WINDOWS_STOP_FILE_NAME = "stop-ds.bat";
 
   /**
    * The UNIX status panel script file name.
    */
-  public static final String UNIX_STATUSPANEL_FILE_NAME = "status-panel";
+  public static final String UNIX_CONTROLPANEL_FILE_NAME = "control-panel";
 
   /**
    * The Windows status panel batch file name.
    */
-  public static final String WINDOWS_STATUSPANEL_FILE_NAME = "status-panel.bat";
+  public static final String WINDOWS_CONTROLPANEL_FILE_NAME =
+    "control-panel.bat";
 
   /**
    * The MacOS X Java application stub name.
@@ -223,9 +224,9 @@
   public static final String MAC_JAVA_APP_STUB_NAME = "JavaApplicationStub";
 
   /**
    * The MacOS X status panel application bundle name.
    */
-  public static final String MAC_STATUSPANEL_FILE_NAME = "StatusPanel.app";
+  public static final String MAC_CONTROLPANEL_FILE_NAME = "ControlPanel.app";
 
   /**
    * The UNIX status command line script file name.
@@ -903,24 +904,24 @@
   }
 
   /**
    * Gets the status panel command file appropriate for the current operating
    * system.
    * @return File object representing the status panel command
    */
-  public File getStatusPanelCommandFile() {
-    File statusPanelCommandFile;
+  public File getControlPanelCommandFile() {
+    File controlPanelCommandFile;
     if (Utils.isWindows()) {
-      statusPanelCommandFile = new File(getBinariesDirectory(),
-              WINDOWS_STATUSPANEL_FILE_NAME);
+      controlPanelCommandFile = new File(getBinariesDirectory(),
+              WINDOWS_CONTROLPANEL_FILE_NAME);
     } else if (Utils.isMacOS()) {
-      statusPanelCommandFile = new File(getRootDirectory() +
+      controlPanelCommandFile = new File(getRootDirectory() +
         File.separator + MAC_APPLICATIONS_PATH_RELATIVE,
-        MAC_STATUSPANEL_FILE_NAME);
+        MAC_CONTROLPANEL_FILE_NAME);
     } else {
-      statusPanelCommandFile = new File(getBinariesDirectory(),
-              UNIX_STATUSPANEL_FILE_NAME);
+      controlPanelCommandFile = new File(getBinariesDirectory(),
+              UNIX_CONTROLPANEL_FILE_NAME);
     }
-    return statusPanelCommandFile;
+    return controlPanelCommandFile;
   }
 
   /**
@@ -208,14 +208,15 @@
 
   /**
-   * The UNIX status panel script file name.
+   * The UNIX control panel script file name.
    */
@@ -208,14 +208,15 @@
 
   /**
-   * The Windows status panel batch file name.
+   * The Windows control panel batch file name.
    */
@@ -223,9 +224,9 @@
 
   /**
-   * The MacOS X status panel application bundle name.
+   * The MacOS X control panel application bundle name.
    */
@@ -903,24 +904,24 @@
 
   /**
-   * Gets the status panel command file appropriate for the current operating
+   * Gets the control panel command file appropriate for the current operating
    * system.
@@ -903,24 +904,24 @@
    * system.
-   * @return File object representing the status panel command
+   * @return File object representing the control panel command
    */

--
Gitblit v1.10.0